@@ -13,10 +13,16 @@ aThread::aThread(QObject *parent)
 void aThread::run()
 {
     QTimer timer;
-    connect(&timer, SIGNAL(timeout()), this, SLOT(updateCoords()));
-    timer.start(20); // 50 Hz update rate
+    connect(&timer, SIGNAL(timeout()), this, SLOT(update()));
+    timer.start(50); // 50 Hz update rate
+
     exec();
 }
+void aThread::update()
+{
+    updateCoords();
+    readProximity();
+}
 
 void aThread::updateCoords()
 {
@@ -28,6 +34,17 @@ void aThread::updateCoords()
      processCoords(data);
 }
 
+void aThread::readProximity()
+{
+    QFile file("/sys/devices/platform/gpio-switch/proximity/state");
+    if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
+        return;
+    QTextStream in(&file);
+    QString data = in.readAll();
+    emit proximityState(data);
+}
+
+
 void aThread::processCoords(QString &data)
 {
     QStringList data_splited = data.split(" ");
