@@ -22,7 +22,7 @@ void DayHistory::showInfo(QModelIndex index)
 
     mid = index.data().toString().indexOf("/");
     group = index.data().toString().left(mid);
-    mid = index.data().toString().count() - mid;
+    mid = index.data().toString().count() - mid - 1;
     name = index.data().toString().right(mid);
 
 
