@@ -63,14 +63,6 @@ ExerciseWindow::ExerciseWindow(QWidget *parent) :
                                             "com.nokia.mafw.renderer",
                                             "resume");
 
-    lock = QDBusMessage::createMethodCall("com.nokia.mce",
-                                          "/com/nokia/mce/request",
-                                          "com.nokia.mce.request",
-                                          "req_tklock_mode_change");
-    QList<QVariant> args;
-    args.append("locked");
-    lock.setArguments(args);
-    QDBusConnection::sessionBus().send(lock);
 
     QDBusMessage reply = interface->call(MCE_ENABLE_VIBRATOR);
     if (reply.type() == QDBusMessage::ErrorMessage)
@@ -108,7 +100,7 @@ void ExerciseWindow::loadExercise(QList<QString> name)
         firstTime = true;
 
     exercises = name;
-    QDBusConnection::sessionBus().send(lock);
+
     QList <QString> tmp;
     QList<QString> settings = xml->loadSettings();
 
@@ -428,7 +420,7 @@ void ExerciseWindow::shaked()
             loadExercise(exercises);
 
             wd = new WeightDialog(this);
-            connect(wd,SIGNAL(next()),this,SLOT(openED()));
+            connect(wd,SIGNAL(next()),this,SLOT(reopenWD()));
             wd->load(currentExercise, currentGroup,"1");
             wd->show();
             return;
@@ -439,12 +431,14 @@ void ExerciseWindow::shaked()
             btnShake->setEnabled(false);
 
             wd = new WeightDialog(this);
+            connect(wd,SIGNAL(next()),this,SLOT(reopenWD()));
             wd->load(currentExercise, currentGroup,"1");
             wd->show();
             return;
         }
 
         wd = new WeightDialog(this);
+        connect(wd,SIGNAL(next()),this,SLOT(reopenWD()));
         wd->load(currentExercise, currentGroup, "1");
         wd->show();
     }
