@@ -1,7 +1,7 @@
 #ifndef NEWPROGRAMWINDOW_H
 #define NEWPROGRAMWINDOW_H
 
-#include <QMainWindow>
+#include <QtGui>
 #include "xml.h"
 
 class NewProgramWindow : public QMainWindow
@@ -9,12 +9,18 @@ class NewProgramWindow : public QMainWindow
     Q_OBJECT
 public:
     explicit NewProgramWindow(QWidget *parent = 0);
-    //QMaemo5Rotator *npwRot;
+    void load();
 signals:
 
 private:
     XML *xml;
-    void load();
+
+    QVBoxLayout *vLayout;
+    QListView *lstExercises;
+    QStandardItemModel *model;
+    QLineEdit *txtName;
+    QPushButton *btnSave;
+
 private slots:
     void saveExercise();
 
