@@ -35,17 +35,20 @@ SettingsWindow::SettingsWindow(QWidget *parent) : QMainWindow(parent)
 void SettingsWindow::showDiet()
 {
     ds = new DietSettings(this);
+    ds->load();
     ds->show();
 }
 
 void SettingsWindow::showOther()
 {
     os = new OtherSettings(this);
+    os->load();
     os->show();
 }
 
 void SettingsWindow::showWeight()
 {
     ws = new WeightSettings(this);
+    ws->load();
     ws->show();
 }
