@@ -23,9 +23,6 @@ WeightDialog::WeightDialog(QWidget *parent) :
     selectorReps->setModel(modelReps);
     btnReps->setPickSelector(selectorReps);
 
-    modelVar = new QStandardItemModel(this);
-    for (int i = 1; i < 10; i++)
-        modelVar->appendRow(new QStandardItem(tr("%1").arg(i)));
 
     btnVar = new QMaemo5ValueButton();
     btnVar->setValueLayout(QMaemo5ValueButton::ValueUnderText);
@@ -77,7 +74,7 @@ void WeightDialog::load(QString name, QString grp, QString currentSet)
 
 
 
-    setWindowTitle("Save weight");
+    setWindowTitle("Save weight (set:" + currentSet + ")");
 
 
 }
@@ -137,7 +134,6 @@ void WeightDialog::save()
     else
         xml->updateHistory(exName,set,weight,reps,status);
 
-    this->hide();
     emit next();
-
+    this->hide();
 }
